# AUTOGENERATED! DO NOT EDIT! File to edit: ../../notebooks/02A-senate-models.ipynb.

# %% auto 0
__all__ = ['Senator', 'SenateCommittee', 'SenateBill']

# %% ../../notebooks/02A-senate-models.ipynb 1
import datetime
import black

from pydantic import BaseModel
from typing import Dict, Optional, List

from ..website import Link

# %% ../../notebooks/02A-senate-models.ipynb 5
class Senator(BaseModel):
    """A member of the Senate"""

    name: str

# %% ../../notebooks/02A-senate-models.ipynb 7
class SenateCommittee(BaseModel):
    """A committee in the Senate"""

    name: str

# %% ../../notebooks/02A-senate-models.ipynb 9
class SenateBill(BaseModel):
    """
    These are general measures, which if passed upon, may become laws.
    A bill is prefixed with S., followed by a number assigned the measure based
    on the order in which it is introduced. The vast majority of legislative
    proposals recommendations dealing with the economy, increasing penalties
    for certain crimes, regulation on commerce and trade, etc., are drafted in
    the form of bills. They also include budgetary appropriation of the
    government and many others. When passed by both chambers in identical
    form and signed by the President or repassed by Congress over a presidential
    veto, they become laws.

    [Definition Source](http://legacy.senate.gov.ph/about/legpro.asp)
    """

    class SenateBillStatus(BaseModel):
        date: datetime.date
        item: str

    class FloorActivity(BaseModel):
        date: datetime.date
        parliamentary_status: str
        senators: Optional[List[Senator]]

    class Subject(BaseModel):
        name: str

    class Vote(BaseModel):
        type: str
        date: datetime.date
        tally: Dict[str, List[Senator]]

    url: str
    congress: int
    billno: str
    congress_text: str
    billno_text: str
    title: str
    long_title: str
    filing_date: datetime.date
    filers: Optional[List[Senator]]
    links: Optional[List[Link]]
    scope: str
    legislative_status: SenateBillStatus
    subjects: Optional[List[Subject]]
    primary_committee: Optional[List[SenateCommittee]]
    secondary_committee: Optional[List[SenateCommittee]]
    committee_reports: Optional[List[Link]]
    sponsors: Optional[List[Senator]]
    cosponsors: Optional[List[Senator]]
    document_certification: Optional[str]
    floor_activity: Optional[List[FloorActivity]]
    votes: Optional[List[Vote]]
    legislative_history: List[SenateBillStatus]

    def __str__(self):
        return f"[{self.billno}] {self.title}"

    def __repr__(self):
        return black.format_str(super().__repr__(), mode=black.Mode())
